install.packages("ape")
install.packages("phytools")
install.packages("geiger")
require(ape)
require(phytools)
require(geiger)

read.tree("concatenatedlept1.nwk") -> concatenatedlept
plot(concatenatedlept)
read.csv("morphological data phylogenetic test.csv") -> lept.dat
data.frame(lept.dat[,3:11]) ->leptData
rownames(leptData) <- lept.dat[,1]
leptData
attach(leptData)
names(pattern) <- rownames(leptData)
names(inner.ring) <- rownames(leptData)
names(spiral.ridges) <- rownames(leptData)
names(AH) <- rownames(leptData)
names(AW) <- rownames(leptData)
names(SpH) <- rownames(leptData)
names(SH) <- rownames(leptData)
names(SW) <- rownames(leptData)
names(SH.SW) <- rownames(leptData)
#Find out taxa that only in tree but not in data
taxa_only_in_tree <- setdiff(concatenatedlept$tip.label, rownames(leptData))
taxa_only_in_tree

# exclude the taxa that only in tree
concatenatedlept <- drop.tip(concatenatedlept, taxa_only_in_tree)
plot(concatenatedlept)

#arranged the taxa in data according to tree
sorted_leptData_according_tree_order <- leptData[concatenatedlept$tip.label,]
str(sorted_leptData_according_tree_order)

#include rownames from sorted data with shell traits
sorted_leptData_according_tree_order[,1] -> shell_pattern
names(shell_pattern) <- row.names(sorted_leptData_according_tree_order) 
shell_pattern
sorted_leptData_according_tree_order[,2] -> spiral_ridges
names(spiral_ridges) <- row.names(sorted_leptData_according_tree_order) 
spiral_ridges
sorted_leptData_according_tree_order[,3] -> inner_ring
names(inner_ring) <- row.names(sorted_leptData_according_tree_order)
inner_ring
sorted_leptData_according_tree_order[,4] -> AH
names(AH) <- row.names(sorted_leptData_according_tree_order)
AH
sorted_leptData_according_tree_order[,5] -> AW
names(AW) <- row.names(sorted_leptData_according_tree_order)
AW
sorted_leptData_according_tree_order[,6] -> SpH
names(SpH) <- row.names(sorted_leptData_according_tree_order)
SpH
sorted_leptData_according_tree_order[,7] -> SH
names(SH) <- row.names(sorted_leptData_according_tree_order)
SH
sorted_leptData_according_tree_order[,8] -> SW
names(SW) <- row.names(sorted_leptData_according_tree_order)
SW
sorted_leptData_according_tree_order[,9] -> SH.SW
names(SH.SW) <- row.names(sorted_leptData_according_tree_order)
SH.SW

# adjust tree
par(mar=c(0,0,0,0))
plot(concatenatedlept, x.lim=c(0,0.75), y.lim=c(0,19),root.edge=False, font=2, cex=1,label.offset=0.01, edge.width=1.5)
add.scale.bar(0,0.05)

#assign colour legend to discrete shell traits
pattern_colour_legend <- character(length(shell_pattern))
pattern_colour_legend
pattern_colour_legend[shell_pattern=="1"]<-"red" 
pattern_colour_legend[shell_pattern=="3"]<-"yellow"
pattern_colour_legend[shell_pattern=="4"]<-"blue"
pattern_colour_legend[shell_pattern=="6"]<-"green"
pattern_colour_legend[shell_pattern=="7"]<-"magenta3"
pattern_colour_legend
points(rep(0.37, 16), 1:16,col="black", bg= pattern_colour_legend, pch=22, cex=4)
inner_ring_colour_legend <- character(length(inner_ring))
inner_ring_colour_legend
inner_ring_colour_legend[inner_ring=="1"]<-"black"
inner_ring_colour_legend[inner_ring=="0"]<-"white"
inner_ring_colour_legend
points(rep(0.39, 16), 1:16, col="black", bg= inner_ring_colour_legend, pch = 22, cex = 4)
spiral_ridges_colour_legend <- character(length(spiral_ridges))
spiral_ridges_colour_legend
spiral_ridges_colour_legend[spiral_ridges=="1"]<-"black"
spiral_ridges_colour_legend[spiral_ridges=="2"]<-"white"
spiral_ridges_colour_legend
points(rep(0.35, 16), 1:16, col="black", bg= spiral_ridges_colour_legend, pch = 22, cex = 4)

#characterizing continuous shell traits
points(rep(0.42, 16), 1:16, col="black",bg="black", pch = 21, cex = sqrt(sorted_leptData_according_tree_order$SH))
points(rep(0.45, 16), 1:16, col="black",bg="black", pch = 21, cex = sqrt(sorted_leptData_according_tree_order$SW))
points(rep(0.48, 16), 1:16, col="black",bg="black", pch = 21, cex = sqrt(sorted_leptData_according_tree_order$AH))
points(rep(0.51, 16), 1:16, col="black",bg="black", pch = 21, cex = sqrt(sorted_leptData_according_tree_order$AW))
points(rep(0.54,16), 1:16, col="black",bg="black", pch = 21, cex = sqrt(sorted_leptData_according_tree_order$SpH))
points(rep(0.57, 16), 1:16, col="black",bg="black", pch = 21, cex = sqrt(sorted_leptData_according_tree_order$SH.SW))

legend(0.545,10.5, title="Shell colour patterns",title.adj=0.53,c("P7","P3","P6", "P4", "P1"), fill=c("magenta3","yellow", "green","blue","red"),bty="n")
legend(0.54,5, title="Dark ring band in aperture",title.adj=0.5,c("presence","absence"), fill=c("black","white"),bty="n")
legend(0.588,13.5, title="Spiral ridges",title.adj=0.05,c("distinct ridges", "weak ridges"), fill=c("black","white"),bty="n")

text(0.38,17.6,labels="Colour patterns",srt=60, cex=0.9)
text(0.40,17.65, labels="Dark ring band", srt=60, cex=0.9)
text(0.36,17.5, labels="Spiral ridges", srt=60, cex=0.9)
text(0.43, 17.5, labels="Shell height", srt=60, cex=0.9)
text(0.46, 17.5, labels="Shell width", srt=60, cex=0.9)
text(0.495, 17.6, labels="Aperture height", srt=60, cex=0.9)
text(0.52, 17.5, labels="Aperture width", srt=60, cex=0.9)
text(0.55, 17.4, labels="Spire height", srt=60, cex=0.9)
text(0.59, 18, labels="Shell height/Shell width", srt=60, cex=0.9)

#phylogenetic signal using Pagel's lambda
#convert phylogram to chronogram
concatenatedlept <- chronopl(concatenatedlept, lambda=0.1)
concatenatedlept<-multi2di(concatenatedlept)
plot(concatenatedlept)

lambda0 <- rescale(concatenatedlept,model="lambda", lambda= 0)
plot(lambda0)
plot(concatenatedlept)
is.ultrametric(concatenatedlept)
is.binary.tree(concatenatedlept)
shell_pattern
shell_pattern<-c(6,3,3,3,1,3,4,4,6,6,6,3,7,7)
names(shell_pattern)<-concatenatedlept$tip.label
shell_pattern
shell_patternlambda <- fitDiscrete(concatenatedlept,shell_pattern, transform="lambda")
shell_patternlambda0 <- fitDiscrete(lambda0, shell_pattern, transform="lambda")
shell_pattern_lambda_chisq <- 1-pchisq((-2*(shell_patternlambda0$opt$lnL))+(2*(shell_patternlambda$opt$lnL)),1)
shell_pattern_lambda_chisq
shell_patternlambda
shell_patternlambda0
inner_ring<-c(0,0,0,0,0,0,0,0,0,0,0,1,1,1)
names(inner_ring)<-concatenatedlept$tip.label
inner_ring
inner_ringlambda <- fitDiscrete(concatenatedlept,inner_ring, transform="lambda")
inner_ringlambda0 <- fitDiscrete(lambda0, inner_ring, transform="lambda")
inner_ring_lambda_chisq <- 1-pchisq((-2*(inner_ringlambda0$opt$lnL))+(2*(inner_ringlambda$opt$lnL)),1)
inner_ring_lambda_chisq
inner_ringlambda
inner_ringlambda0

spiral_ridges<-c(2,2,2,2,2,2,1,1,1,1,1,1,1,1)
names(spiral_ridges)<-concatenatedlept$tip.label
spiral_ridges
spiral_ridgeslambda <- fitDiscrete(concatenatedlept,spiral_ridges, transform="lambda")
spiral_ridgeslambda0 <- fitDiscrete(lambda0, spiral_ridges, transform="lambda")
spiral_ridges_lambda_chisq <- 1-pchisq((-2*(spiral_ridgeslambda0$opt$lnL))+(2*(spiral_ridgeslambda$opt$lnL)),1)
spiral_ridges_lambda_chisq
spiral_ridgeslambda
spiral_ridgeslambda0

AHlambda <- fitContinuous(concatenatedlept, AH, model="lambda")
AHlambda0 <- fitContinuous(lambda0, AH, model="lambda")
AH_lambda_chisq <- 1-pchisq((-2*(AHlambda0$opt$lnL))+(2*(AHlambda$opt$lnL)),1)
AH_lambda_chisq
AHlambda
AHlambda0

SHlambda <- fitContinuous(concatenatedlept, SH, model="lambda")
SHlambda0 <- fitContinuous(lambda0, SH, model="lambda")
SH_lambda_chisq <- 1-pchisq((-2*(SHlambda0$opt$lnL))+(2*(SHlambda$opt$lnL)),1)
SH_lambda_chisq
SHlambda
SHlambda0

AWlambda <- fitContinuous(concatenatedlept, AW, model="lambda")
AWlambda0 <- fitContinuous(lambda0, AW, model="lambda")
AW_lambda_chisq <- 1-pchisq((-2*(AWlambda0$opt$lnL))+(2*(AWlambda$opt$lnL)),1)
AW_lambda_chisq
AWlambda
AWlambda0

SpHlambda <- fitContinuous(concatenatedlept, SpH, model="lambda")
SpHlambda0 <- fitContinuous(lambda0, SpH, model="lambda")
SpH_lambda_chisq <- 1-pchisq((-2*(SpHlambda0$opt$lnL))+(2*(SpHlambda$opt$lnL)),1)
SpH_lambda_chisq
SpHlambda 
SpHlambda0

SWlambda <- fitContinuous(concatenatedlept, SW, model="lambda")
SWlambda0 <- fitContinuous(lambda0, SW, model="lambda")
SW_lambda_chisq <- 1-pchisq((-2*(SWlambda0$opt$lnL))+(2*(SWlambda$opt$lnL)),1)
SW_lambda_chisq
SWlambda
SWlambda0

SH.SWlambda <- fitContinuous(concatenatedlept, SH.SW, model="lambda")
SH.SWlambda0 <- fitContinuous(lambda0, SH.SW, model="lambda")
SH.SW_lambda_chisq <- 1-pchisq((-2*(SH.SWlambda0$opt$lnL))+(2*(SH.SWlambda$opt$lnL)),1)
SH.SW_lambda_chisq
SH.SWlambda 
SH.SWlambda0

#phylogenetic signal test using Blomberg's K
phylosig(concatenatedlept, shell_pattern, method="K", test=T)
phylosig(concatenatedlept, inner_ring, method="K", test=T)
phylosig(concatenatedlept, spiral_ridges, method="K", test=T)
phylosig(concatenatedlept, AH, method="K", test=T)
phylosig(concatenatedlept, AW, method="K", test=T)
phylosig(concatenatedlept, SpH, method="K", test=T)
phylosig(concatenatedlept, SH, method="K", test=T)
phylosig(concatenatedlept, SW, method="K", test=T)
phylosig(concatenatedlept, SH.SW, method="K", test=T)

